import React, { useState } from 'react';
import { Link, useNavigate } from 'react-router-dom';
import Sidebar from '../sidebar/Sidebar';
import axiosInstance from '../../api/axiosConfig';

const AddEmployee = () => {
  const navigate = useNavigate();
  const [employeeData, setEmployeeData] = useState({
    firstname: '',
    lastname: '',
    age: '',
    gender: '',
    email: '',
    address: '',
    mobile: '',
  });

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setEmployeeData({
      ...employeeData,
      [name]: value,
    });
  };

  const handleAddEmployeeSubmit = async (e) => {
    e.preventDefault();
    try {
      await axiosInstance.post('/employees', employeeData);
      navigate('/employees');
    } catch (error) {
      console.error('Error adding employee:', error.response || error.message);
    }
  };

  return (
    <div className="flex flex-row">
      <Sidebar />
      <div className="w-full flex flex-col min-h-screen text-black">
        <div className="min-h-screen text-gray-800 p-6">
          <div className="flex justify-between items-center mb-6">
            <h1 className="text-2xl font-semibold text-blue-900">creating employee account</h1>
            <Link to="/" className="text-blue-900">Skip for now</Link>
          </div>
          <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
            <div className="space-y-6">
              <div className="text-center">
                <div className="inline-block relative">
                  <div className="bg-gray-300 w-24 h-24 rounded-full mx-auto"></div>
                  <button className="absolute bottom-0 left-1/2 transform -translate-x-1/2 bg-#4b5563 text-white text-xs px-2 py-1 rounded-full">
                    add employee image
                  </button>
                </div>
              </div>
            </div>
            <div className="md:col-span-2 space-y-4">
              <form onSubmit={handleAddEmployeeSubmit}>
                <div>
                  <label className="block text-gray-800 font-medium">employee firstname:</label>
                  <input
                    type="text"
                    name="firstname"
                    value={employeeData.firstname}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-#4b5563"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">employee lastname:</label>
                  <input
                    type="text"
                    name="lastname"
                    value={employeeData.lastname}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-#4b5563"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">age:</label>
                  <input
                    type="number"
                    name="age"
                    value={employeeData.age}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-#4b5563"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">gender:</label>
                  <select
                    name="gender"
                    value={employeeData.gender}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-#4b5563"
                  >
                    <option value="" disabled>Select Gender</option>
                    <option value="male">male</option>
                    <option value="female">female</option>
                    <option value="other">other</option>
                  </select>
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">email:</label>
                  <input
                    type="email"
                    name="email"
                    value={employeeData.email}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-#4b5563"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">address:</label>
                  <input
                    type="text"
                    name="address"
                    value={employeeData.address}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-#4b5563"
                  />
                </div>
                <div>
                  <label className="block text-gray-800 font-medium">mobile no:</label>
                  <input
                    type="text"
                    name="mobile"
                    value={employeeData.mobile}
                    onChange={handleInputChange}
                    className="input-underline w-full p-2 border-b border-gray-400 focus:border-#4b5563"
                  />
                </div>
                <br />
                <div className="text-center">
                  <button type="submit" className="bg-#0e355b text-#d1d5db px-4 py-2 rounded-md font-semibold">
                    create account
                  </button>
                </div>
              </form>
            </div>
          </div>
        </div>
      </div>
    </div>
  );
};

export default AddEmployee;
